
//
// cle4vdr 2005 - 2014 by Alexander Hans <cle4vdr@arcor.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
// Or, point your browser to http://www.gnu.org/copyleft/gpl.html
//


unit ushow;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, ComCtrls, Dialogs, Graphics, Forms, StdCtrls, Grids, StrUtils;

procedure ShowOverview(n: TTreeNode);
procedure ShowTVOverview(n: TTreeNode);
function IndexOfMap(a: array of String; str: String): Integer;
procedure ShowExpert(n: TTreeNode);
procedure ShowParams(n: TTreeNode);
procedure ShowAudio(n: TTreeNode);
procedure ShowDolby(n: TTreeNode);
procedure ShowSubtitles(n: TTreeNode);
procedure ClearEditFields;

implementation

uses uinterface, uchannels;


procedure ShowOverview(n: TTreeNode);
begin
  if n <> NIL then with cleP(n.Data)^ do
  begin
    frmMain.edName.Text      := Name;
    frmMain.edShort.Text     := Short;
    frmMain.edProvider.Text  := Provider;
    frmMain.edNumber.Text    := IntToStr(Number);
  
    frmMain.edType.Text := ChannelType(n);
    

    if NOT isGroupSep(n) then
    begin
      frmMain.lbNumber.Caption := 'Number';
      frmMain.cbSource.Enabled := true;
      if (length(Source) > 0) then
      begin
        if (Source[1] = 'S') then
        begin
          if System = '1' then frmMain.edKind.Text := 'DVB-S2'
          else frmMain.edKind.Text := 'DVB-S';
        end
        else if Source[1] = 'C' then frmMain.edKind.Text := 'DVB-C'
        else if Source[1] = 'T' then frmMain.edKind.Text := 'DVB-T'
        else if Source[1] = 'P' then frmMain.edKind.Text := 'IPTV'
        else if Source[1] = 'A' then frmMain.edKind.Text := 'ATSC'
        else frmMain.edKind.Text := 'unknown';
      end;


      frmMain.lbEdLanguage.Caption := LanguagesToStr(n);
      frmMain.lbEdEncryption.Caption := EncryptionsToStr(n);

      // ********** Icons **************//
      if TTpid <> '0' then frmMain.ilIcons.GetBitmap(1, frmMain.imTeletext.Picture.Bitmap)
      else frmMain.ilIcons.GetBitmap(0, frmMain.imTeletext.Picture.Bitmap);

      if HasDolby(n) then frmMain.ilIcons.GetBitmap(3, frmMain.imDolby.Picture.Bitmap)
      else frmMain.ilIcons.GetBitmap(2, frmMain.imDolby.Picture.Bitmap);

      if isEncrypted(n)
        then frmMain.ilIcons.GetBitmap(5, frmMain.imEncrypted.Picture.Bitmap)
        else frmMain.ilIcons.GetBitmap(4, frmMain.imEncrypted.Picture.Bitmap);;

      if HasMultiLang(n) then
        frmMain.ilIcons.GetBitmap(7, frmMain.imMulti.Picture.Bitmap)
      else
        frmMain.ilIcons.GetBitmap(6, frmMain.imMulti.Picture.Bitmap);

      if cleP(n.Data)^.System = '1' then frmMain.lbHDTV.Font.Color := clYellow
      else if cleP(n.Data)^.System = '0' then frmMain.lbHDTV.Font.Color := $004D4D4D;
    end
    else
    begin
      frmMain.cbSource.Enabled := false;
      frmMain.lbNumber.Caption := 'Contains';
      frmMain.edNumber.Text := IntToStr(n.Count) + ' Channels';
      frmMain.imTeletext.Picture.Bitmap := NIL;
      frmMain.imDolby.Picture.Bitmap := NIL;
      frmMain.imEncrypted.Picture.Bitmap := NIL;
      frmMain.imMulti.Picture.Bitmap := NIL;
      frmMain.lbHDTV.Font.Color := $00755A2F;
      frmMain.edShort.Text := '';
      frmMain.edProvider.Text := '';
      frmMain.edSource.Text := '';
      frmMain.edKind.Text := '';
      frmMain.lbEdLanguage.Caption := '';
      frmMain.lbEdEncryption.Caption := '';
    end;
  end;
end;


procedure ShowTVOverview(n: TTreeNode);
begin
  if n = NIL then exit;
  if NOT isGroupSep(TTreeNode(n.Data)) then with cleP(TTreeNode(n.Data).Data)^ do
  begin
    frmMain.lbtvName.Caption          := Name;
    frmMain.lbtvProvider.Caption      := Provider;
    frmMain.lbtvPosition.Caption      := '';

    if (length(Source) > 0) then
    begin
      if (Source[1] = 'S') then
      begin
        if System = '1' then frmMain.lbtvSource.Caption := 'DVB-S2'
        else frmMain.lbtvSource.Caption := 'DVB-S';
        frmMain.lbtvPosition.Caption    := Source;
      end
      else if Source[1] = 'C' then frmMain.lbtvSource.Caption := 'DVB-C'
      else if Source[1] = 'T' then frmMain.lbtvSource.Caption := 'DVB-T'
      else if Source[1] = 'P' then frmMain.lbtvSource.Caption := 'IPTV'
      else if Source[1] = 'A' then frmMain.lbtvSource.Caption := 'ATSC'
      else frmMain.lbtvSource.Caption := 'unknown';
    end;

    frmMain.lbtvPolarisation.Caption := PolToStr(Pol);
    frmMain.lbtvFrequency.Caption    := Frequency;
    frmMain.lbtvSymbolrate.Caption   := Symbolrate;
  end
  else
  begin
    frmMain.lbtvName.Caption          := '';
    frmMain.lbtvProvider.Caption      := '';
    frmMain.lbtvPosition.Caption      := '';
    frmMain.lbtvSource.Caption        := '';
    frmMain.lbtvPolarisation.Caption  := '';
    frmMain.lbtvFrequency.Caption     := '';
    frmMain.lbtvSymbolrate.Caption    := '';
  end;
end;


function IndexOfMap(a: array of String; str: String): Integer;
var
  i: Integer;
begin
  for i := 0 to Length(a) - 1 do
    if a[i] = str then
    begin
      result := i;
      Exit;
    end;
  result := -1;
end;

procedure ShowExpert(n: TTreeNode);
begin
  if n <> NIL then with cleP(n.Data)^ do
  begin
    frmMain.edNameExp.Text     := Name;
    frmMain.edShortExp.Text    := Short;
    frmMain.edProviderExp.Text := Provider;
    frmMain.edFrequencyExp.Text      := Frequency;
    frmMain.edSymbolrateExp.Text     := Symbolrate;
    frmMain.cbSourceExp.Caption      := Source;
    frmMain.cbSource.ItemIndex       := frmMain.cbSourceExp.ItemIndex;

    if frmMain.cbSource.Caption <> '' then
      frmMain.edSource.Text          := frmMain.cbSource.Caption
    else frmMain.edSource.Text       := Source;

    frmMain.cbPol.ItemIndex          := IndexOfMap(PolMap, LowerCase(cleP(n.Data)^.Pol));

    frmMain.edVid.Text               := VideoPid;
    frmMain.edVidType.Text           := VideoType;
    frmMain.edPcr.Text               := PcrPid;
    frmMain.edTeletext.Text          := TTpid;
    frmMain.edSid.Text               := Sid;
    frmMain.edNit.Text               := Nid;
    frmMain.edCa.Text                := Ca;
    frmMain.edTid.Text               := Tid;
    frmMain.edRad.Text               := Rid;
    
    frmMain.edChanId.Text            := ChannelID(n);;

    ShowParams(n);
    ShowAudio(n);
    ShowDolby(n);
    ShowSubtitles(n);
  end;
end;




procedure ShowParams(n: TTreeNode);
begin
  frmMain.cbAlpha.Text              := cleP(n.Data)^.Alpha;
  frmMain.cbCodeRH.ItemIndex        := IndexOfMap(CodeRHMap, cleP(n.Data)^.CodeRH);
  frmMain.cbCodeRL.ItemIndex        := IndexOfMap(CodeRHMap, cleP(n.Data)^.CodeRL);
  frmMain.cbGuard.ItemIndex         := IndexOfMap(GuardMap, cleP(n.Data)^.Guard);
  frmMain.cbMod.ItemIndex           := IndexOfMap(ModulationMap, cleP(n.Data)^.Modulation);
  if cleP(n.Data)^.StreamID = '' then frmMain.cbStreamID.ItemIndex := -1
  else frmMain.cbStreamID.ItemIndex := StrToInt(cleP(n.Data)^.StreamID);
  frmMain.cbHierarchy.ItemIndex     := IndexOfMap(HierarchyMap, cleP(n.Data)^.Hierarchy);
  frmMain.cbBandwidth.ItemIndex     := IndexOfMap(BandwidthMap, cleP(n.Data)^.Bandwidth);
  frmMain.cbInversion.ItemIndex     := IndexOfMap(InversionMap, cleP(n.Data)^.Inversion);
  frmMain.cbRolloff.ItemIndex       := IndexOfMap(RolloffMap, cleP(n.Data)^.RollOff);
  frmMain.cbTransmission.ItemIndex  := IndexOfMap(TransmissionMap, cleP(n.Data)^.TransmissionMode);
  frmMain.cbSystem.ItemIndex        := IndexOfMap(SystemMap, cleP(n.Data)^.System);
  
  frmMain.cbSourceExp.Text          := cleP(n.Data)^.Source;
end;


procedure ShowAudio(n: TTreeNode);
var
  i: Integer;
begin
  frmMain.sgAudio.Clean;
  if (n = NIL) OR (cleP(n.Data)^.AudioPids = NIL) OR (Length(cleP(n.Data)^.AudioPids) = 0) then Exit;
  frmMain.sgAudio.RowCount := Length(cleP(n.Data)^.AudioPids)+1;
  for i := 0 to Length(cleP(n.Data)^.AudioPids)-1 do
  begin
    if cleP(n.Data)^.Audiopids[i, 0] = '0' then exit;
    frmMain.sgAudio.Cells[0, i+1] := cleP(n.Data)^.Audiopids[i,0];
    frmMain.sgAudio.Cells[1, i+1] := cleP(n.Data)^.Audiopids[i,1];
    frmMain.sgAudio.Cells[2, i+1] := cleP(n.Data)^.Audiopids[i,2];
  end;
end;

procedure ShowDolby(n: TTreeNode);
var
  i: Integer;
begin
  frmMain.sgDolby.Clean;
  if (n = NIL) OR (cleP(n.Data)^.AC3Pids = NIL) OR (Length(cleP(n.Data)^.AC3Pids) = 0) then Exit;
  frmMain.sgDolby.RowCount := Length(cleP(n.Data)^.AC3Pids)+1;
  for i := 0 to Length(cleP(n.Data)^.AC3Pids) - 1 do
  begin
    if cleP(n.Data)^.AC3Pids[i,0] = '0' then exit;
    frmMain.sgDolby.Cells[0, i+1] := cleP(n.Data)^.AC3Pids[i,0];
    frmMain.sgDolby.Cells[1, i+1] := cleP(n.Data)^.AC3Pids[i,1];
    frmMain.sgDolby.Cells[2, i+1] := cleP(n.Data)^.AC3Pids[i,2];
  end;
end;

procedure ShowSubtitles(n: TTreeNode);
var
  i: Integer;
begin
  frmMain.sgSubttl.Clean;
  if (n = NIL) OR (cleP(n.Data)^.SubtPids = NIL) OR (cleP(n.Data)^.SubtPids.Count = 0) then Exit;
  frmMain.sgSubttl.RowCount := cleP(n.Data)^.SubtPids.Count+1;
  for i := 0 to cleP(n.Data)^.SubtPids.Count - 1 do
  begin
    if cleP(n.Data)^.SubtPids[i] = '0' then exit;
    frmMain.sgSubttl.Cells[0, i+1] := cleP(n.Data)^.SubtPids.Names[i];
    frmMain.sgSubttl.Cells[1, i+1] := cleP(n.Data)^.SubtPids.ValueFromIndex[i];
  end;
end;

procedure ClearEditFields;
var
  i: Integer;
begin
  for i := 0 to Application.MainForm.ComponentCount - 1 do
  begin
    if (Application.MainForm.Components[i].ClassName = 'TEdit') then
        (Application.MainForm.Components[i] as TEdit).Text := ''
    else if (Application.MainForm.Components[i].ClassName = 'TComboBox') then
        (Application.MainForm.Components[i] as TComboBox).Text := ''
    else if (Application.MainForm.Components[i].ClassName = 'TStringGrid') then
        (Application.MainForm.Components[i] as TStringGrid).Clean
    else if AnsiStartsStr('lbtv', Application.MainForm.Components[i].Name) then
            if (((Application.MainForm.Components[i] as TLabel).Font.Style = []) OR
                (Application.MainForm.Components[i].Name = 'lbtvName')) then
        (Application.MainForm.Components[i] as TLabel).Caption := ''
  end;
  frmMain.lbEdEncryption.Caption := '';
  frmMain.lbEdLanguage.Caption   := '';
  frmMain.imTeletext.Picture.Bitmap := NIL;
  frmMain.imDolby.Picture.Bitmap := NIL;
  frmMain.imEncrypted.Picture.Bitmap := NIL;
  frmMain.imMulti.Picture.Bitmap := NIL;
  frmMain.lbHDTV.Font.Color := $00755A2F;
end;

end.

